camelot.camelot.view.controls.navpane.NavigationPane

Package camelot :: Package camelot :: Package view :: Package controls :: Module navpane :: Class NavigationPane |
[hide private]
[frames] | no frames]

# Class NavigationPane

source code

ms office-like navigation pane in Qt

Instance Methods | [hide private]
__init__(self, app_admin, objectname='NavigationPane', parent=None) | source code
setcontent(self, buttons) | source code
set_models_in_tree(self, models) | source code
change_current(self, (index, text)) | source code
createContextMenu(self, point) | source code
popWindow(self) pops a model window in parent's workspace | source code